CREATE DATABASE IF NOT EXISTS myanimelist_db;

USE myanimelist_db;


CREATE EXTERNAL TABLE IF NOT EXISTS score (
    user_id INT,
    anime_id INT,
    rating INT
)
ROW FORMAT SERDE 'org.apache.hadoop.hive.serde2.OpenCSVSerde'
WITH SERDEPROPERTIES (
    "separatorChar" = ',',
    "quoteChar"     = '\"',
    "escapeChar"    = '\\'
)
TBLPROPERTIES ("skip.header.line.count"="1")
LOCATION '/dataset/score';


CREATE EXTERNAL TABLE IF NOT EXISTS anime (
    anime_id INT,
    name VARCHAR(255),
    english_name VARCHAR(255),
    other_name VARCHAR(255),
    score DECIMAL(3,2),
    genres VARCHAR(255),
    synopsis STRING,
    type VARCHAR(50),
    episodes INT,
    aired VARCHAR(255),
    premiered VARCHAR(50),
    status VARCHAR(50),
    producers STRING,
    licensors STRING,
    studios STRING,
    source VARCHAR(100),
    duration VARCHAR(50),
    rating VARCHAR(50),
    rank INT,
    popularity INT,
    favorites INT,
    scored_by INT,
    members INT,
    image_url STRING
)
ROW FORMAT SERDE 'org.apache.hadoop.hive.serde2.OpenCSVSerde'
WITH SERDEPROPERTIES (
    "separatorChar" = ',',
    "quoteChar"     = '\"',
    "escapeChar"    = '\\'
)
TBLPROPERTIES ("skip.header.line.count"="1")
LOCATION '/dataset/anime';

CREATE EXTERNAL TABLE IF NOT EXISTS users (
    mal_id INT,
    username STRING,
    gender STRING,
    birthday TIMESTAMP,
    location STRING,
    joined TIMESTAMP,
    days_watched FLOAT,
    mean_score FLOAT,
    watching FLOAT,
    completed FLOAT,
    on_hold FLOAT,
    dropped FLOAT,
    plan_to_watch FLOAT,
    total_entries FLOAT,
    rewatched FLOAT,
    episodes_watched FLOAT
)
ROW FORMAT SERDE 'org.apache.hadoop.hive.serde2.OpenCSVSerde'
WITH SERDEPROPERTIES (
    "separatorChar" = ',',
    "quoteChar"     = '\"',
    "escapeChar"    = '\\'
)
TBLPROPERTIES ("skip.header.line.count"="1")
LOCATION '/dataset/users';




